From 44c45c050bfc017e3fffc2d0bb762d2fa9affa7e Mon Sep 17 00:00:00 2001
From: Aditya Vidyadhar Kamath <Aditya.Kamath1@ibm.com>
Date: Wed, 16 Nov 2022 04:30:59 -0600
Subject: [PATCH] Fix call functions command bug in 64 bits programs for AIX

In AIX for 64 bit programs we need to zero extend variables of integer data type.

Otherwise a zero will get dumped in the register as we memset our word to 0 and integer is not extended.

This patch is a fix for the same.
---
 gdb/rs6000-aix-tdep.c | 7 ++++++-
 1 file changed, 6 insertions(+), 1 deletion(-)

diff --git a/gdb/rs6000-aix-tdep.c b/gdb/rs6000-aix-tdep.c
index d47974b51d1..a7d174d8be8 100644
--- a/gdb/rs6000-aix-tdep.c
+++ b/gdb/rs6000-aix-tdep.c
@@ -400,7 +400,12 @@ rs6000_push_dummy_call (struct gdbarch *gdbarch, struct value *function,
 	  gdb_byte word[PPC_MAX_REGISTER_SIZE];
 
 	  memset (word, 0, reg_size);
-	  memcpy (word, value_contents (arg).data (), len);
+          if (type->code () == TYPE_CODE_INT)
+                /* Sign or zero extend the "int" into a "word".  */
+                store_unsigned_integer (word, tdep->wordsize, byte_order,
+                                        unpack_long (type, value_contents (arg).data ()));
+          else
+		memcpy (word, value_contents (arg).data (), len);
 	  regcache->cooked_write (tdep->ppc_gp0_regnum + 3 +ii, word);
 	}
       ++argno;
-- 
2.31.1

